import SwiftUI

enum Example: String, CaseIterable {
    case weatherKit = "WeatherKit"
    case mapKit = "MapKit"
    case focusFilter = "Focus Filter"
    case variableColor = "Variable Color"
    case visionKit = "VisionKit"
}

struct ContentView: View {
    var body: some View {
        NavigationStack {
            List {
                ForEach(Example.allCases, id: \.self) { example in
                    NavigationLink(example.rawValue, value: example)
                }
            }
            .navigationDestination(for: Example.self) { example in
                Group {
                    switch example {
                    case .weatherKit:
                        WeatherKitExample()
                    case .mapKit:
                        MapKitExample()
                    case .focusFilter:
                        FocusFilterExample()
                    case .variableColor:
                        VariableColorExample()
                    case .visionKit:
                        VisionKitExample()
                    }
                }
                .navigationTitle(example.rawValue)
            }
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
