import SwiftUI

import MapKit

struct MapView: UIViewRepresentable {
    typealias UIViewType = MKMapView

    func makeUIView(context: Context) -> MKMapView {
        let mapView = MKMapView()
        mapView.preferredConfiguration = MKStandardMapConfiguration()
        return mapView
    }

    func updateUIView(_ uiView: MKMapView, context: Context) {
    }
}

struct LookAround: UIViewControllerRepresentable {
    typealias UIViewControllerType = MKLookAroundViewController

    @Binding var scene: MKLookAroundScene?

    func makeUIViewController(context: Context) -> MKLookAroundViewController {
        let vc = MKLookAroundViewController()
        vc.scene = scene
        vc.delegate = context.coordinator
        return vc
    }

    func updateUIViewController(_ uiViewController: MKLookAroundViewController, context: Context) {
        uiViewController.scene = scene
    }

    func makeCoordinator() -> Coordinator {
        return Coordinator(scene: $scene)
    }

    class Coordinator: NSObject, MKLookAroundViewControllerDelegate {
        let scene: Binding<MKLookAroundScene?>

        init(scene: Binding<MKLookAroundScene?>) {
            self.scene = scene
        }

        func lookAroundViewControllerDidUpdateScene(_ viewController: MKLookAroundViewController) {
            self.scene.wrappedValue = viewController.scene
        }
    }
}

struct MapKitExample: View {
    @State private var scene: MKLookAroundScene? = nil

    var body: some View {
        ZStack(alignment: .bottomLeading) {
            MapView()
                .edgesIgnoringSafeArea(.all)
            LookAround(scene: $scene)
                .frame(width: 300, height: 200)
                .cornerRadius(8)
                .padding()
        }
        .task {
            let request = MKLookAroundSceneRequest(
                coordinate: CLLocationCoordinate2D(
                    latitude: 35.6895014,
                    longitude: 139.6917337
                )
            )
            do {
                scene = try await request.scene
            } catch {
                print(error)
            }
        }
    }
}

struct MapKitExample_Previews: PreviewProvider {
    static var previews: some View {
        MapKitExample()
    }
}
