//
//  VisionKitExample.swift
//  Examples
//
//  Created by Kouki Saito on 2022/10/23.
//

import SwiftUI
import PhotosUI
import VisionKit

struct VisionKitExample: UIViewControllerRepresentable {
    func makeUIViewController(context: Context) -> VisionViewController {
        UIStoryboard(name: "VisionViewController", bundle: .main).instantiateInitialViewController() as! VisionViewController
    }

    func updateUIViewController(_ uiViewController: VisionViewController, context: Context) {
    }
}

class VisionViewController: UIViewController {
    let analyzer = ImageAnalyzer()
    let interaction = ImageAnalysisInteraction()

    @IBOutlet private var imageView: UIImageView!

    override func viewDidLoad() {
        super.viewDidLoad()
        imageView.addInteraction(interaction)
    }

    func analyzeAndSetImage(image: UIImage) {
        imageView.image = image
        Task {
            let configuration = ImageAnalyzer.Configuration([.text])
            let analysis = try await analyzer.analyze(image, configuration: configuration)
            interaction.analysis = analysis
        }
    }

    @IBAction func showAlbum() {
        var configuration = PHPickerConfiguration()
        configuration.selectionLimit = 1
        configuration.filter = .images
        let picker = PHPickerViewController(configuration: configuration)
        picker.delegate = self
        present(picker, animated: true)
    }
}

extension VisionViewController: PHPickerViewControllerDelegate {
    func picker(_ picker: PHPickerViewController, didFinishPicking results: [PHPickerResult]) {
        picker.dismiss(animated: true)
        if let result = results.first, result.itemProvider.canLoadObject(ofClass: UIImage.self) {
            result.itemProvider.loadObject(ofClass: UIImage.self) { [weak self] image, _ in
                guard let image = image as? UIImage else {
                    return
                }
                DispatchQueue.main.async {
                    self?.analyzeAndSetImage(image: image)
                }
            }
        }
    }
}
