import SwiftUI

import CoreLocation
import WeatherKit

import SafariServicesUI

@MainActor
class CurrentWeather: ObservableObject {
    @Published private(set) var attribution: WeatherAttribution? = nil
    @Published private(set) var weather: Weather?

    func load() async throws {
        let service = WeatherService.shared
        attribution = try await service.attribution
        let tokyo = CLLocation(latitude: 35.6895014, longitude: 139.6917337)
        weather = try await service.weather(for: tokyo)
    }
}

struct WeatherAttributionView: View {
    @Environment(\.colorScheme) var colorScheme
    let attribution: WeatherAttribution

    var body: some View {
        VStack {
            AsyncImage(
                url: colorScheme == .dark
                ? attribution.combinedMarkDarkURL
                : attribution.combinedMarkLightURL
            ) { image in
                image
                    .resizable()
                    .scaledToFit()
                    .frame(height: 20)
            } placeholder: {
            }
            Link("Other Data Sources",
                 destination: attribution.legalPageURL)
            .openURLInSafariView()
        }
    }
}

struct WeatherKitExample: View {
    @StateObject private var currentWeather = CurrentWeather()

    var body: some View {
        VStack {
            if let weather = currentWeather.weather {
                Text(weather.currentWeather.condition.description)
                Text(weather.currentWeather.temperature.formatted())
            }
            if let attribution = currentWeather.attribution {
                WeatherAttributionView(attribution: attribution)
            }
        }
        .task {
            do {
                try await currentWeather.load()
            } catch {
                print(error)
            }
        }
    }
}

struct WeatherKitExample_Previews: PreviewProvider {
    static var previews: some View {
        WeatherKitExample()
    }
}
