import SwiftUI

enum Examples: String, Hashable, CaseIterable {
    case grid = "Grid"
    case anyLayout = "AnyLayout"
    case customLayout = "CustomLayout"
    case viewThatFits = "ViewThatFits"
    case transferable = "Transferable"
    case pasteButton = "PasteButton"
    case presentationDetent = "PresentationDetent"
    case labeledContent = "LabeledContent"
    case table = "Table"
    case imageRenderer = "ImageRenderer"
    case photosPicker = "PhotosPicker"
    case uiKit = "UIKit"
}

struct ContentView: View {
    var body: some View {
        NavigationStack {
            List(Examples.allCases, id: \.self) { example in
                NavigationLink(example.rawValue, value: example)
            }
            .navigationDestination(for: Examples.self) { example in
                Group {
                    switch example {
                    case .grid:
                        GridExample()
                    case .anyLayout:
                        AnyLayoutExample()
                    case .customLayout:
                        CustomLayoutExample()
                    case .viewThatFits:
                        ViewThatFitsExample()
                    case .transferable:
                        TransferableExample()
                    case .pasteButton:
                        PasteButtonExample()
                    case .presentationDetent:
                        PresentationDetentExample()
                    case .labeledContent:
                        LabeledContentExample()
                    case .table:
                        TableExample()
                    case .imageRenderer:
                        ImageRendererExample()
                    case .photosPicker:
                        PhotosPickerExample()
                    case .uiKit:
                        UIKitExample()
                    }
                }
                .navigationTitle(example.rawValue)
            }
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
