import SwiftUI

class Clock: ObservableObject {
    @Published private(set) var date: Date = Date.now

    init() {
        Timer.publish(
            every: 1,
            on: .main,
            in: .common
        ).autoconnect().assign(to: &$date)
    }
}

struct ClockView: View {
    @StateObject private var clock = Clock()

    var body: some View {
        Text(clock.date, format: .dateTime.second())

    }
}

struct ImageRendererExample2: View {
    @StateObject var renderer = ImageRenderer(content: ClockView())

    var body: some View {
        if let image = renderer.cgImage {
            Image(image, scale: renderer.scale, label: Text(""))
        }
    }
}

struct ImageRendererExample: View {
    @State var image: Image? = nil
    @State var text: String = ""

    var body: some View {
        VStack {
            if let image {
                image
            }
            HStack {
                TextField("Text", text: $text)
                Button("Generate") {
                    let renderer = ImageRenderer(content: Text(text))
                    if let cgImage = renderer.cgImage {
                        image = Image(decorative: cgImage, scale: renderer.scale)
                    }
                }
            }
        }
    }
}

struct ImageRendererExample_Previews: PreviewProvider {
    static var previews: some View {
        ImageRendererExample()
    }
}
