import SwiftUI

struct Release: Hashable {
    let version: String
    let build: String
    let date: Date
}

extension Release: Identifiable {
    var id: String {
        return version
    }
}

private let calendar = Calendar(identifier: .gregorian)
let initialReleases = [
    Release(version: "iPhone OS 1", build: "1A543a", date: DateComponents(calendar: calendar, year: 2007, month: 6, day: 29).date!),
    Release(version: "iPhone OS 2", build: "5A347", date: DateComponents(calendar: calendar, year: 2008, month: 7, day: 11).date!),
    Release(version: "iPhone OS 3", build: "7A341", date: DateComponents(calendar: calendar, year: 2009, month: 6, day: 17).date!),
    Release(version: "iOS 4", build: "8A293", date: DateComponents(calendar: calendar, year: 2010, month: 6, day: 21).date!),
    Release(version: "iOS 5", build: "9A334", date: DateComponents(calendar: calendar, year: 2011, month: 10, day: 12).date!),
    Release(version: "iOS 6", build: "10A403", date: DateComponents(calendar: calendar, year: 2012, month: 9, day: 19).date!),
    Release(version: "iOS 7", build: "11A465", date: DateComponents(calendar: calendar, year: 2013, month: 9, day: 18).date!),
    Release(version: "iOS 8", build: "12A365", date: DateComponents(calendar: calendar, year: 2014, month: 9, day: 17).date!),
    Release(version: "iOS 9", build: "13A344", date: DateComponents(calendar: calendar, year: 2015, month: 9, day: 16).date!),
    Release(version: "iOS 10", build: "14A346", date: DateComponents(calendar: calendar, year: 2016, month: 9, day: 13).date!),
    Release(version: "iOS 11", build: "15A372", date: DateComponents(calendar: calendar, year: 2017, month: 9, day: 19).date!),
    Release(version: "iOS 12", build: "16A366", date: DateComponents(calendar: calendar, year: 2018, month: 9, day: 17).date!),
    Release(version: "iOS 13", build: "17A577", date: DateComponents(calendar: calendar, year: 2019, month: 9, day: 19).date!),
    Release(version: "iOS 14", build: "18A373", date: DateComponents(calendar: calendar, year: 2020, month: 9, day: 16).date!),
    Release(version: "iOS 15", build: "19A346", date: DateComponents(calendar: calendar, year: 2021, month: 9, day: 20).date!),
    Release(version: "iOS 16", build: "20A362", date: DateComponents(calendar: calendar, year: 2022, month: 9, day: 12).date!),
]

struct TableExample: View {
    @State private var releases = initialReleases
    @State private var sortOrder: [KeyPathComparator<Release>] = []

    var sortedReleases: [Release] {
        return releases.sorted(using: sortOrder)
    }

    var body: some View {
        Table(sortedReleases, sortOrder: $sortOrder) {
            TableColumn("Version", value: \.version)
            TableColumn("Build", value: \.build)
            TableColumn("Date", value: \.date) { release in
                Text(release.date, format: .dateTime.year().month().day())
            }
        }
    }
}

struct TableExample_Previews: PreviewProvider {
    static var previews: some View {
        TableExample()
    }
}
