import SwiftUI

class PasteControlExampleViewController: UIViewController {
    override func viewDidLoad() {
        super.viewDidLoad()
        let textField = UITextField()
        textField.placeholder = "URL"
        let configuration = UIPasteControl.Configuration()
        configuration.displayMode = .iconAndLabel
        let pasteControl = UIPasteControl(configuration: configuration)
        pasteControl.target = textField
        let stackView = UIStackView(arrangedSubviews: [
            textField,
            pasteControl,
        ])
        view.addSubview(stackView)
        stackView.translatesAutoresizingMaskIntoConstraints = false
        NSLayoutConstraint.activate([
            stackView.topAnchor.constraint(equalTo: view.topAnchor),
            stackView.leadingAnchor.constraint(equalTo: view.leadingAnchor),
            stackView.trailingAnchor.constraint(equalTo: view.trailingAnchor),
            stackView.bottomAnchor.constraint(equalTo: view.bottomAnchor),
        ])
    }
}

struct UIPasteControllExample: UIViewControllerRepresentable {
    typealias UIViewControllerType = PasteControlExampleViewController

    func makeUIViewController(context: Context) -> PasteControlExampleViewController {
        PasteControlExampleViewController()
    }

    func updateUIViewController(_ uiViewController: PasteControlExampleViewController, context: Context) {

    }
}

struct PasteButtonExample: View {
    @State private var url1: URL? = nil
    @State private var url2: URL? = nil

    var body: some View {
        List {
            Section {
                Button("Copy") {
                    UIPasteboard.general.url = URL(string: "https://www.apple.com")
                }
            }
            Section {
                HStack {
                    TextField("URL", text: .constant(url1?.absoluteString ?? ""))
                    PasteButton(payloadType: URL.self) { urls in
                        url1 = urls.first
                    }
                }
            }
            Section {
                HStack {
                    TextField("URL", text: .constant(url2?.absoluteString ?? ""))
                    PasteButton(supportedContentTypes: [.url]) { itemProviders in
                        for itemProvider in itemProviders {
                            itemProvider.loadObject(ofClass: URL.self) { url, error in
                                if let url {
                                    url2 = url
                                }
                            }.resume()
                        }
                    }
                }
            }

            Section {
                UIPasteControllExample()
            }
        }
    }
}

struct PasteButtonExample_Previews: PreviewProvider {
    static var previews: some View {
        PasteButtonExample()
    }
}
