import SwiftUI

class UIKitExampleViewController: UIViewController {
    private lazy var collectionView: UICollectionView = {
        let listConfiguration = UICollectionLayoutListConfiguration(appearance: .grouped)
        let layout = UICollectionViewCompositionalLayout.list(using: listConfiguration)
        return UICollectionView(frame: view.bounds, collectionViewLayout: layout)
    }()

    private lazy var dataSource: UICollectionViewDiffableDataSource<Int, Release> = {
        let cellRegistration = UICollectionView.CellRegistration<UICollectionViewListCell, Release> { cell, indexPath, item in
            cell.contentConfiguration = UIHostingConfiguration {
                LabeledContent(item.version, value: item.date, format: .dateTime)
                    .swipeActions {
                        Button("Delete") {
                            print("delete")
                        }
                    }
            }
        }
        return UICollectionViewDiffableDataSource(
            collectionView: self.collectionView,
            cellProvider: { collectionView, indexPath, device in
                return collectionView.dequeueConfiguredReusableCell(
                    using: cellRegistration,
                    for: indexPath,
                    item: device)
            }
        )
    }()

    override func viewDidLoad() {
        super.viewDidLoad()

        view.addSubview(collectionView)

        var snapshot = dataSource.snapshot(for: 0)
        snapshot.append(initialReleases)
        dataSource.apply(snapshot, to: 0)
    }
}

struct UIKitExample: UIViewControllerRepresentable {
    typealias UIViewControllerType = UIKitExampleViewController

    func makeUIViewController(context: Context) -> UIKitExampleViewController {
        return UIKitExampleViewController()
    }

    func updateUIViewController(_ uiViewController: UIKitExampleViewController, context: Context) {
        
    }
}

struct UIKitExample_Previews: PreviewProvider {
    static var previews: some View {
        UIKitExample()
    }
}
