import Foundation
import Combine

struct Directory: Codable, Hashable {
    let url: URL
}

@MainActor
class DirectoryModel: ObservableObject {
    private let fileManager = FileManager.default

    let directory: Directory

    @Published private(set) var name: String = ""
    @Published private(set) var items: [FileSystemItem] = []

    init(directory: Directory) {
        self.directory = directory
    }

    func createFile(name: String) -> File? {
        let url = directory.url.appending(path: name, directoryHint: .notDirectory)
        guard fileManager.createFile(atPath: url.path(), contents: nil) else {
            return nil
        }
        try? load()
        return File(url: url)
    }

    func createDirectory(name: String) throws -> Directory {
        let url = directory.url.appending(path: name, directoryHint: .isDirectory)
        try fileManager.createDirectory(atPath: url.path(), withIntermediateDirectories: true)
        try load()
        return Directory(url: url)
    }

    func removeFile(_ file: File) throws {
        try fileManager.removeItem(at: file.url)
        try load()
    }

    func removeDirectory(_ directory: Directory) throws {
        try fileManager.removeItem(at: directory.url)
        try load()
    }

    func load() throws {
        let urls = try fileManager.contentsOfDirectory(at: directory.url, includingPropertiesForKeys: [.isDirectoryKey])
        items = try urls.map { url in
            let resource = try url.resourceValues(forKeys: [.isDirectoryKey])
            return resource.isDirectory! ? FileSystemItem.directory(Directory(url: url)) : FileSystemItem.file(File(url: url))
        }
        name = fileManager.displayName(atPath: directory.url.path)
    }
}
