//
//  LineAreaChart.swift
//  ChartsExample
//
//  Created by Yutaro Muta on 2022/09/24.
//

import SwiftUI
import Charts

struct LineAreaChart: View {
    private let summaries: [BuildSummary] = BuildSummary.data

    var body: some View {
        List {
            Chart(summaries) { summary in
                LineMark(x: .value("Day", summary.date),
                         y: .value("Average", summary.average))
                AreaMark(x: .value("Day", summary.date),
                         yStart: .value("Min", summary.min),
                         yEnd: .value("Max", summary.max))
                .opacity(0.2)
            }
            .chartXAxis {
                AxisMarks(values: .stride(by: .day)) {
                    AxisGridLine()
                    AxisTick()
                    AxisValueLabel(
                        format: .dateTime.weekday(.abbreviated)
                    )
                }
            }
            .frame(height: 300)
        }
        .navigationTitle(String(describing: type(of: self)))
    }
}

struct RuleAreaChart_Previews: PreviewProvider {
    static var previews: some View {
        LineAreaChart()
    }
}
