//
//  RectangleBarChart.swift
//  ChartsExample
//
//  Created by Yutaro Muta on 2022/09/24.
//

import SwiftUI
import Charts

struct RectangleBarChart: View {
    private let summaries: [BuildSummary] = BuildSummary.data

    var body: some View {
        List {
            Chart(summaries) { summary in
                RectangleMark(x: .value("Day",
                                        summary.date,
                                        unit: .day),
                              y: .value("Average",
                                        summary.average),
                              height: 2)
                BarMark(x: .value("Day",
                                  summary.date,
                                  unit: .day),
                        yStart: .value("Min", summary.min),
                        yEnd: .value("Max", summary.max))
                .opacity(0.2)
            }
            .chartXAxis {
                AxisMarks(values: .stride(by: .day)) {
                    AxisGridLine()
                    AxisTick()
                    AxisValueLabel(
                        format: .dateTime.weekday(.abbreviated)
                    )
                }
            }
            .frame(height: 300)
        }
        .navigationTitle(String(describing: type(of: self)))
    }
}

struct RectangleBarChart_Previews: PreviewProvider {
    static var previews: some View {
        RectangleBarChart()
    }
}
