//
//  BarChart.swift
//  ChartsExample
//
//  Created by Yutaro Muta on 2022/09/19.
//

import SwiftUI
import Charts

struct BarChart: View {
    @State private var isOnBuilds: Bool = true
    @State private var isOnTests: Bool = true
    @State private var isPositionEnabled: Bool = false

    private let jobs: [Job] = Job.data

    var body: some View {
        List {
            VStack {
                Toggle("Builds", isOn: $isOnBuilds.animation(.easeInOut))
                Toggle("Tests", isOn: $isOnTests.animation(.easeInOut))
            }
            Chart(jobs) { job in
                if isOnBuilds {
                    BarMark(
                        x: .value("Start", job.startAt, unit: .hour),
                        y: .value("Duration", job.build)
                    )
                    .if(isPositionEnabled) {
                        $0.position(by: .value("Job", "Builds"))
                    }
                    .foregroundStyle(by: .value("Job", "Builds"))
                }
                if isOnTests {
                    BarMark(
                        x: .value("Start", job.startAt, unit: .hour),
                        y: .value("Duration", job.test)
                    )
                    .if(isPositionEnabled) {
                        $0.position(by: .value("Job", "Tests"))
                    }
                    .foregroundStyle(by: .value("Job", "Tests"))
                }
            }
            .chartYScale(domain: 0...400)
            .chartXAxis {
                AxisMarks(values: .stride(by: .hour)) {
                    AxisGridLine()
                    AxisTick()
                    AxisValueLabel(
                        format: .relative(presentation: .named)
                    )
                }
            }
            .chartForegroundStyleScale([
                "Builds": .blue,
                "Tests": .yellow,
            ])
            .frame(height: 300)
            Toggle("Bar Position", isOn: $isPositionEnabled.animation(.easeInOut))
        }
        .navigationTitle(String(describing: type(of: self)))
    }
}

struct BarChart_Previews: PreviewProvider {
    static var previews: some View {
        BarChart()
    }
}
