//
//  LineChart.swift
//  ChartsExample
//
//  Created by Yutaro Muta on 2022/09/23.
//

import SwiftUI
import Charts

struct LineChart: View {
    @State private var isOnBuilds: Bool = true
    @State private var isOnTests: Bool = true

    private let jobs: [Job] = Job.data

    var body: some View {
        List {
            VStack {
                Toggle("Builds", isOn: $isOnBuilds.animation(.easeInOut))
                Toggle("Tests", isOn: $isOnTests.animation(.easeInOut))
            }
            Chart(jobs) { job in
                if isOnBuilds {
                    LineMark(
                        x: .value("Start", job.startAt, unit: .hour),
                        y: .value("Duration", job.build)
                    )
                    .symbol(.circle)
                    .symbolSize(100)
                    .foregroundStyle(by: .value("Job", "Builds"))
                }
                if isOnTests {
                    LineMark(
                        x: .value("Start", job.startAt, unit: .hour),
                        y: .value("Duration", job.test)
                    )
                    .symbol(.cross)
                    .symbolSize(100)
                    .foregroundStyle(by: .value("Job", "Tests"))
                }
            }
            .chartYScale(domain: 0...400)
            .chartXAxis {
                AxisMarks(values: .stride(by: .hour)) {
                    AxisGridLine()
                    AxisTick()
                    AxisValueLabel(
                        format: .relative(presentation: .named)
                    )
                    .font(.system(size: 8))
                }
            }
            .chartForegroundStyleScale([
                "Builds": .blue,
                "Tests": .yellow,
            ])
            .frame(height: 300)
        }
        .navigationTitle(String(describing: type(of: self)))
    }
}

struct LineChart_Previews: PreviewProvider {
    static var previews: some View {
        LineChart()
    }
}
