//
//  ContentView.swift
//  ChartsExample
//
//  Created by Yutaro Muta on 2022/09/18.
//

import SwiftUI
import Charts

struct ContentView: View {
    private enum Destinations {
        case bar
        case line
        case area
        case rectangleBar
        case lineArea
    }

    @State private var selection: Destinations?

    var body: some View {
        NavigationSplitView {
            List(selection: $selection) {
                Section("Job") {
                    NavigationLink("Bar", value: Destinations.bar)
                    NavigationLink("Line", value: Destinations.line)
                    NavigationLink("Area", value: Destinations.area)
                }
                Section("BuildSummary") {
                    NavigationLink("RectangleBar", value: Destinations.rectangleBar)
                    NavigationLink("LineArea", value: Destinations.lineArea)
                }
            }
            .navigationTitle("Charts")
            .listStyle(.insetGrouped)
        } detail: {
            NavigationStack {
                switch selection {
                case .bar:
                    BarChart()
                case .line:
                    LineChart()
                case .area:
                    AreaChart()
                case .rectangleBar:
                    RectangleBarChart()
                case .lineArea:
                    LineAreaChart()
                case nil:
                    EmptyView()
                }
            }
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
