//
//  Views.swift
//  WidgetExample
//
//  Created by Kouki Saito on 2022/10/23.
//

import SwiftUI

struct LuminanceView: View {
  @Environment(\.isLuminanceReduced)
  var isLuminanceReduced

  var body: some View {
    if isLuminanceReduced {
      Text("低い更新頻度のコンテンツ")
    } else {
      Text("通常のコンテンツ")
    }
  }
}

struct PrivacySensitiveView: View {
  var body: some View {
    Text("口座残高: \(12345)円")
      .privacySensitive()
  }
}

struct DateIntervalView: View {
  var body: some View {
    let start = Date.now - 100
    let end = start + 100
    ProgressView(timerInterval: start...end)
  }
}

struct TextCountdownView: View {
  var body: some View {
    Text(timerInterval: Date.now...(Date.now+100))
  }
}

struct Views_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            LuminanceView()
                .environment(\.isLuminanceReduced, false)
            LuminanceView()
                .environment(\.isLuminanceReduced, true)
            PrivacySensitiveView()
                .environment(\.redactionReasons, [])
            PrivacySensitiveView()
                .environment(\.redactionReasons, [.privacy])
            DateIntervalView()
            TextCountdownView()
        }.padding()
    }
}
